summaryrefslogtreecommitdiff
path: root/src/ide/highlight.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/ide/highlight.rs')
-rw-r--r--src/ide/highlight.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/ide/highlight.rs b/src/ide/highlight.rs
index 6214328b..e948975b 100644
--- a/src/ide/highlight.rs
+++ b/src/ide/highlight.rs
@@ -27,9 +27,9 @@ pub enum Tag {
ListMarker,
/// A term in a term list.
ListTerm,
- /// The delimiters of a math formula.
+ /// The delimiters of an equation.
MathDelimiter,
/// An operator with special meaning in a math formula.
MathOperator,
/// A keyword.
Keyword,
@@ -138,7 +138,7 @@ pub fn highlight(node: &LinkedNode) -> Option<Tag> {
SyntaxKind::EnumMarker => Some(Tag::ListMarker),
SyntaxKind::TermItem => None,
SyntaxKind::TermMarker => Some(Tag::ListMarker),
- SyntaxKind::Formula => None,
+ SyntaxKind::Equation => None,
SyntaxKind::Math => None,
SyntaxKind::MathIdent => highlight_ident(node),
@@ -27,9 +27,9 @@ pub enum Tag {
MathDelimiter,
- /// An operator with special meaning in a math formula.
+ /// An operator with special meaning in an equation.
MathOperator,
/// A keyword.